excluders

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 29, 2020 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type RobotsTxtExcluder

type RobotsTxtExcluder struct {
	// contains filtered or unexported fields
}

RobotsTxtExcluder bases its exclusion rules on a given robots.txt file

func NewRobotsTxtExcluder

func NewRobotsTxtExcluder(agent string, enable bool, url *urlpkg.URL) (*RobotsTxtExcluder, error)

func (*RobotsTxtExcluder) Exclude

func (t *RobotsTxtExcluder) Exclude(path string) bool

Exclude checks against the rules found in the robots.txt file to see if a given path should be excluded. It allows all paths if disabled.

Jump to