Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RobotsTxtExcluder ¶
type RobotsTxtExcluder struct {
// contains filtered or unexported fields
}
RobotsTxtExcluder bases its exclusion rules on a given robots.txt file
func NewRobotsTxtExcluder ¶
func (*RobotsTxtExcluder) Exclude ¶
func (t *RobotsTxtExcluder) Exclude(path string) bool
Exclude checks against the rules found in the robots.txt file to see if a given path should be excluded. It allows all paths if disabled.
Click to show internal directories.
Click to hide internal directories.